## $Id: interfaces.py 12485 2015-01-18 08:59:35Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

from zope import schema
from datetime import datetime
from waeup.ikoba.customers.interfaces import (
    ICustomer, ICustomerDocument, ICustomerPDFDocument, IContract,
    validate_email)
from waeup.ikoba.customers.vocabularies import (
    ConCatProductSource, CustomerDocumentSource, nats_vocab)
from waeup.ikoba.schema import TextLineChoice, FormattedDate, PhoneNumber
from waeup.ikoba.products.productoptions import ProductOptionField
from ikobacustom.pcn.interfaces import MessageFactory as _
from ikobacustom.pcn.interfaces import LGASource

def year_range():
    curr_year = datetime.now().year
    return range(curr_year - 2, curr_year + 5)

class IPCNCustomer(ICustomer):
    """Representation of a customer.

    """

# Customer document interfaces


class IPCNCustomerJPGDocument(ICustomerDocument):
    """A customer jpg document.

    """

class IPCNCustomerPDFDocument(ICustomerPDFDocument):
    """A customer pdf document.

    """

# Customer contract interfaces

class IRONContract(IContract):
    """A Retention Of Name  contract.

    """

    date_of_birth = FormattedDate(
        title = _(u'Date of Birth'),
        required = True,
        show_year = True,
        )

    state_of_origin = schema.Choice(
        vocabulary = nats_vocab,
        title = _(u'State of Origin'),
        required = False,
        )

    lga = schema.Choice(
        source = LGASource(),
        title = _(u'State / LGA'),
        required = True,
        )

    year_qualification = schema.Choice(
        title = _(u'Year of Qualification'),
        required = True,
        values = year_range(),
        )

    res_address = schema.Text(
        title = _(u'Residential Address'),
        required = True,
        )

    res_address = schema.Text(
        title = _(u'Residential Address'),
        required = False,
        )

    work_address = schema.Text(
        title = _(u'Work Address'),
        required = False,
        )

    work_email = schema.ASCIILine(
        title = _(u'Work Email Address'),
        required = False,
        constraint=validate_email,
        )

    work_phone = PhoneNumber(
        title = _(u'Work Phone'),
        description = u'',
        required = False,
        )

    category_practice = schema.TextLine(
        title = _(u'Category of Practice'),
        description = _(u'academic, retail and dispensing, hospital, administrative, wholesale, importation, manufacturing, etc.'),
        required = False,
        )

    superintendent = schema.Bool(
        title= _('Superintendent'),
        description= _('Tick box if you are a superintendent pharamcist.'),
        required = False,
        )

    #document_object = schema.Choice(
    #    title = _(u'Document'),
    #    source = CustomerDocumentSource(),
    #    required = False,
    #    )

class IRONContractProcess(IRONContract):
    """Interface for processing RON data.
    """

    product_options = schema.List(
        title = _(u'Options/Fees'),
        value_type = ProductOptionField(),
        required = False,
        readonly = False,
        default = [],
        )

class IRONContractEdit(IRONContract):
    """Interface for editing RON data by customers.

    """

    product_object = schema.Choice(
        title = _(u'Product'),
        source = ConCatProductSource(),
        required = True,
        )

    #document_object = schema.Choice(
    #    title = _(u'Document'),
    #    source = CustomerDocumentSource(),
    #    required = True,
    #    )
